boolean optimizePlt(int plotFileNumber) {
  String fileName=nf(plotFileNumber, 5)+".PLT";

  File f = dataFile(fileName);
  String filePath = f.getPath();
  boolean exist = f.isFile();

  if (exist) {

    /// ----------------------------------------- load all vectors from .PLT file into array

    BufferedReader reader = createReader("data/"+fileName);
    String line = null;
    int vectorCount=0;

    xStart[vectorCount]=1;
    yStart[vectorCount]=1;

    try {
      while ((line = reader.readLine()) != null) {
        String[] pieces = split(line, ",");
        if (int(pieces[3])==1) {
          xStart[vectorCount]=int(pieces[1]);
          yStart[vectorCount]=int(pieces[2]);
        }
        if (int(pieces[3])==255) {
          xEnd[vectorCount]=int(pieces[1]);
          yEnd[vectorCount]=int(pieces[2]);
          vectorCount++;
          xStart[vectorCount]=int(pieces[1]);
          yStart[vectorCount]=int(pieces[2]);
        }
      }

      reader.close();
    } 
    catch (IOException e) {
      e.printStackTrace();
    }

    /// ----------------------------------------- find and remove double vectors

    int v2Count=0;

    for (int i=0; i<vectorCount; i++) {
      boolean doubleVector=false;
      for (int k=0; k<i; k++) {
        if (
          (xStart[i]==xStart[k] && yStart[i]==yStart[k] && xEnd[i]==xEnd[k] && yEnd[i]==yEnd[k])
          ||
          (xStart[i]==xEnd[k] && yStart[i]==yEnd[k] && xEnd[i]==xStart[k] && yEnd[i]==yStart[k])
          ) {
          doubleVector=true;
        }
      }
      if (!doubleVector) {
        xS2[v2Count]=xStart[i];
        yS2[v2Count]=yStart[i];
        xE2[v2Count]=xEnd[i];
        yE2[v2Count]=yEnd[i];
        v2Count++;
      }
    }

    /// ----------------------------------------- delete intermediate points

    int v3Count=0;

    xS3[0]=xS2[0];
    yS3[0]=yS2[0];
    xE3[0]=xE2[0];
    yE3[0]=yE2[0];
    for (int i=1; i<v2Count; i++) {
      if (
        ((xS2[i-1]-xE2[i-1] == xS2[i]-xE2[i]) && (yS2[i-1]-yE2[i-1] == yS2[i]-yE2[i]))
        &&
        (xE2[i-1]==xS2[i] && yE2[i-1]==yS2[i])
        ) {
        // vector has same direction and last vector ends where new vector starts: set new endpoint
        xE3[v3Count]=xE2[i];
        yE3[v3Count]=yE2[i];
      } else {
        // vector has different direction: set new start & endpoint
        v3Count++;
        xS3[v3Count]=xS2[i];
        yS3[v3Count]=yS2[i];
        xE3[v3Count]=xE2[i];
        yE3[v3Count]=yE2[i];
      }
    }

    /// ----------------------------------------- write optimized .PLT file

    PrintWriter output;
    output = createWriter("vektordaten/optimizedPLT/"+fileName);
    for (int i=0; i<=v3Count; i++) {

      output.println("2,"+xS3[i]+","+yS3[i]+",1"); // Write the coordinate to the file
      output.println("2,"+xE3[i]+","+yE3[i]+",255");
    }
    output.flush(); // write the data to the file
    output.close(); // finish the file


   // println("-------");
   // println("orig:"+vectorCount+" clean:"+v2Count+" optimized:"+v3Count);
  }
  return (exist);
}
